@@ -2,14 +2,12 @@
 
 """ Methods that concern splice junctions - getting their coordinates, transcription starts/ends, phases. """
 
-
 import logging
 import os.path
 import pandas as pd
 import statistics
 
 from jcast import params
-from jcast.annots import AnnotatedTranscript
 
 class RmatsResults(object):
     """
@@ -190,7 +188,11 @@ class Junction(object):
     @property
     def min_read_count(self):
         """
-        A setter to mark the minimum read count in the junction
+        Returns the minimum read count in the junction. if rMATS was run with one technical replicate,
+        the count field is an int, otherwise it is a list. Currently this takes the skipped junction count (SJC)
+        as filtering criterion because the majority of translatable events are probably SE (skipped exon).
+        Essentially this filters out alternative junctions that are very rarely skipped (high inclusion
+        level of the exons) that are not likely to be translatable.
 
         :return:
         """
@@ -204,36 +206,6 @@ class Junction(object):
 
         return min([mean_count_sample1, mean_count_sample2])
 
-
-    def get_annotated_transcripts(self, gtf):
-        """
-        prepping for future versions.
-        get the annotated transcripts of the gene under question
-
-        :param gtf: genome annotation
-
-        """
-
-        # first, subset the gtf by the gene under question
-        gtf_gene = gtf.annot.query('gene_id == @self.gene_id')
-
-        # then get a list of all transcripts that are protein_coding, has coding sequences,
-        # and has transcript support level equal to or below the threashold
-
-        tsl = params.tsl_threshold
-        filter_tx = gtf_gene.query('feature == "CDS" & '
-                                            'transcript_biotype == "protein_coding" & '
-                                            'transcript_support_level <= @tsl')
-        coding_tx = filter_tx[['transcript_name']].drop_duplicates().values.tolist()
-
-        # for each qualifying transcripts, get all the CDS
-
-        for tx in coding_tx:
-            pass
-
-
-
-
     def _get_translated_region(self,
                                gtf,
                                startsite_index: int = 0,
@@ -256,7 +228,6 @@ class Junction(object):
         #
         tsl = params.tsl_threshold
 
-
         # 2020-07-25 now getting the start codons of all protein coding transcripts at TSL threshold
         gtf0_start = gtf0.query('feature == "start_codon" & '
                                 'transcript_biotype == "protein_coding" & '
@@ -276,11 +247,11 @@ class Junction(object):
         # 2020-07-25 now getting end codons of all protein coding transcripts at TSL threshold
         try:
             gtf0_end = gtf0.query('feature == "start_codon" & '
-                                'transcript_biotype == "protein_coding" & '
+                                  'transcript_biotype == "protein_coding" & '
                                   'transcript_support_level <= @tsl').loc[:, 'start'].drop_duplicates()
 
         except KeyError:
-            pass
+            gtf0_end = None
 
         # Get the longest transcripts (highest coordinates if strand is +)
         if len(gtf0_end) > 0:
@@ -289,7 +260,7 @@ class Junction(object):
             self.tx1 = -1
 
         #
-        # By rMATS convention, if strand is -ve
+        # by rMATS convention, if strand is -ve
         # then the upstream is near the end of tx
         # shift by 2 to get to the end of the end codon.
         #
@@ -303,7 +274,8 @@ class Junction(object):
         self.logger.debug('Chosen start codon is {0}; end codon is {1}; tsl is {2}.'.format(self.tx0,
                                                                                             self.tx1,
                                                                                             tsl,
-                                                                                           ))
+                                                                                            )
+                          )
         return True
 
     def get_translated_phase(self, gtf):
@@ -313,11 +285,11 @@ class Junction(object):
         :return:
         """
 
-        #
-        # Get translation phase from GTF file.
-        # If there is no phase found in the GTF, use phase -1 for now.
-        # To do: look more closely into GTF file, or try translating from all frames
-        #
+        """
+        Get translation phase from GTF file.
+        If there is no phase found in the GTF, use phase -1 for now.
+        # TODO: look more closely into GTF file, or try translating from all frames
+        """
 
         # Subset the gtf file
         gtf0 = gtf.annot.query('gene_id == @self.gene_id')
@@ -353,10 +325,8 @@ class Junction(object):
                 # ph0, ph1 = self.alt1_es, self.alt1_ee
                 ph0, ph1 = self.anc_es, self.anc_ee
 
-
-        self.logger.info('Anchor start {0} end {1}'.format(ph0,
-                                                           ph1))
-
+        self.logger.info('Anchor exon start {0} Anchor exon end {1}'.format(ph0,
+                                                                            ph1))
 
         # Get the frame of that coding exon from GTF.
         coding_exon = gtf0.query('start == @ph0').\
@@ -370,7 +340,7 @@ class Junction(object):
             # TODO: find the canonical transcript
 
         else:
-            self.phase = -1     # dummy value to trigger trying different phases for longest translation
+            self.phase = None     # dummy value to trigger trying different phases for longest translation
             # TODO: handle phase retrieval failure in a tidier manner
 
 
@@ -378,8 +348,6 @@ class Junction(object):
                                                                                self.tx1))
         self.logger.info('Retrieved phase: {0}'.format(self.phase))
 
-
-
     def trim_cds(self, gtf):
         """
         Wrapper to trimming the exons by CDS; first retrieve the coordinates of the translation starts and ends,
@@ -389,8 +357,6 @@ class Junction(object):
         if self.tx0 is None:
             self._get_translated_region(gtf=gtf,
                                         startsite_index=0)
-            self.logger.info('Anchor exon start: {0} Anchor exon end: {1}'.format(self.anc_es,
-                                                                                  self.anc_ee))
 
         self._trim()
 
@@ -411,7 +377,7 @@ class Junction(object):
 
     def _trim(self):
         """
-        core trim function that shaves off the UTRs
+        Core trim function that shaves off the UTRs
         :return: True
 
         Trims the junction based on transcription start and end:
@@ -422,7 +388,6 @@ class Junction(object):
         # Subset the gtf file by the current gene_id
         #
 
-
         if self.junction_type == 'MXE':
             try:
                 if self.anc_ee > self.tx0 > self.anc_es:
@@ -437,7 +402,8 @@ class Junction(object):
                     self.anc_es = -1
                     self.anc_ee = -1
                     self.alt2_es = self.tx0
-            except:
+
+            except TypeError or ValueError:
                 self.logger.info('Trimming start failed.')
 
             try:
@@ -453,7 +419,8 @@ class Junction(object):
                     self.down_es = -1
                     self.down_ee = -1
                     self.alt2_ee = self.tx1
-            except:
+
+            except TypeError or ValueError:
                 self.logger.info('Trimming end failed.')
 
         elif self.junction_type == 'SE':
@@ -466,7 +433,7 @@ class Junction(object):
                     self.anc_ee = -1
                     self.alt1_es = self.tx0
 
-            except:
+            except TypeError or ValueError:
                 self.logger.info('Trimming start failed.')
 
             try:
@@ -478,7 +445,7 @@ class Junction(object):
                     self.down_ee = -1
                     self.alt1_ee = self.tx1
 
-            except:
+            except TypeError or ValueError:
                 self.logger.info('Trimming end failed.')
 
         elif self.junction_type == 'RI':
@@ -486,14 +453,14 @@ class Junction(object):
                 if self.anc_ee > self.tx0 > self.anc_es:
                     self.anc_es = self.tx0
 
-            except:
+            except TypeError or ValueError:
                 self.logger.info('Trimming start failed.')
 
             try:
                 if self.down_ee > self.tx1 > self.down_es:
                     self.down_ee = self.tx1
 
-            except:
+            except TypeError or ValueError:
                 self.logger.info('Trimming end failed.')
 
         elif self.junction_type == 'A5SS':
@@ -504,14 +471,14 @@ class Junction(object):
                 if self.alt1_ee > self.tx0 > self.alt1_es:
                     self.alt1_es = self.tx0
 
-            except:
+            except TypeError or ValueError:
                 self.logger.info('Trimming start failed.')
 
             try:
                 if self.anc_ee > self.tx1 > self.anc_es:
                     self.anc_ee = self.tx1
 
-            except:
+            except TypeError or ValueError:
                 self.logger.info('Trimming end failed.')
 
         elif self.junction_type == 'A3SS':
@@ -519,7 +486,7 @@ class Junction(object):
                 if self.anc_ee > self.tx0 > self.anc_es:
                     self.anc_es = self.tx0
 
-            except:
+            except TypeError or ValueError:
                 self.logger.info('Trimming start failed.')
 
             try:
@@ -529,8 +496,7 @@ class Junction(object):
                 if self.alt2_ee > self.tx1 > self.alt2_es:
                     self.alt2_ee = self.tx1
 
-            except:
+            except TypeError or ValueError:
                 self.logger.info('Trimming end failed.')
 
-
         return True
